@@ -4,8 +4,8 @@
 #' parameters in parallel, spread across multiple nodes of a SLURM cluster. 
 #' 
 #' This function creates a temporary folder ("_rslurm_[jobname]") in the current
-#' directory, holding the .RData files, the R script and the Bash submission 
-#' script generated for the SLURM job. 
+#' directory, holding .RData and .RDS data files, the R script to run and the Bash
+#' submission script generated for the SLURM job. 
 #' 
 #' The set of input parameters is divided in equal chunks sent to each node, and 
 #' \code{f} is evaluated in parallel within each node using functions from the
@@ -23,7 +23,7 @@
 #' 
 #' When processing the computation job, the SLURM cluster will output two types
 #' of files in the temporary folder: those containing the return values of the
-#' function for each subset of parameters ("results_[node_id].RData") and those
+#' function for each subset of parameters ("results_[node_id].RDS") and those
 #' containing any console or error output produced by R on each node
 #' ("slurm_[node_id].out").
 #' 
@@ -61,8 +61,9 @@
 #'   Details below for more information. 
 #' @param submit Whether or not to submit the job to the cluster with 
 #'   \code{sbatch}; see Details below for more information.
-#' @return A \code{slurm_job} object containing the \code{jobname} and the 
-#'   number of \code{nodes} effectively used.
+#' @return A \code{slurm_job} object containing the \code{jobname}, the 
+#'   number of \code{nodes} effectively used, and if \code{submit = TRUE} the
+#'   \code{jobid}.
 #' @seealso \code{\link{slurm_call}} to evaluate a single function call.
 #' @seealso \code{\link{cancel_slurm}}, \code{\link{cleanup_files}}, 
 #'   \code{\link{get_slurm_out}} and \code{\link{print_job_status}} 
@@ -99,9 +100,9 @@ slurm_apply <- function(f, params, jobname = NA, nodes = 2, cpus_per_node = 2,
     
     # Create temp folder
     tmpdir <- paste0("_rslurm_", jobname)
-    dir.create(tmpdir)
+    dir.create(tmpdir, showWarnings = FALSE)
     
-    saveRDS(params, file = file.path(tmpdir, "params.RData"))
+    saveRDS(params, file = file.path(tmpdir, "params.RDS"))
     if (!is.null(add_objects)) {
         save(list = add_objects, file = file.path(tmpdir, "add_objects.RData"))
     }    
@@ -140,17 +141,18 @@ slurm_apply <- function(f, params, jobname = NA, nodes = 2, cpus_per_node = 2,
                          rscript = rscript_path))
     writeLines(script_sh, file.path(tmpdir, "submit.sh"))
     
-    
     # Submit job to SLURM if applicable
+    if (submit && system('squeue', ignore.stdout = TRUE)) {
+        submit <- FALSE
+        cat("Cannot submit; no SLURM workload manager on path\n")
+    }
     if (submit) {
-        old_wd <- setwd(tmpdir)
-        tryCatch({
-            system("sbatch submit.sh")
-        }, finally = setwd(old_wd))
+        jobid <- submit_slurm_job(tmpdir)
     } else {
+        jobid <- NULL
         cat(paste("Submission scripts output in directory", tmpdir))
     }
-
-    # Return 'slurm_job' object with jobname, number of nodes
-    slurm_job(jobname, nodes)
+    
+    # Return 'slurm_job' object
+    slurm_job(jobname, nodes, jobid)
 }
