@@ -14,12 +14,13 @@ test_that("slurm_job name is correctly edited", {
     expect_equal(sjob$jobname, "test_call")
 })
 
-olddir <- getwd()
-rscript_path <- file.path(R.home("bin"), "Rscript")
-setwd(paste0("_rslurm_", sjob$jobname))
-tryCatch(system(paste(rscript_path, "--vanilla slurm_run.R")), 
-         finally = setwd(olddir))
-res <- get_slurm_out(sjob)
+sjob <- local_slurm_array(sjob)
+# olddir <- getwd()
+# rscript_path <- file.path(R.home("bin"), "Rscript")
+# setwd(paste0("_rslurm_", sjob$jobname))
+# tryCatch(system(paste(rscript_path, "--vanilla slurm_run.R")), 
+#          finally = setwd(olddir))
+res <- get_slurm_out(sjob, wait = FALSE)
 
 test_that("slurm_call returns correct output", {
     expect_equal(res, 16)
@@ -27,4 +28,4 @@ test_that("slurm_call returns correct output", {
 
 # Pause to make sure temporary folder is free to be deleted
 Sys.sleep(1)
-cleanup_files(sjob)
+cleanup_files(sjob, wait = FALSE)
